# What is Pikuli?

Pikuli is a tool initially inspired by [Sikuli Project](http://www.sikuli.org). Currently Pikuli helps to automate GUI scenarios (aka tests) in Windows and Linux.

Pikuli can:
* Look for UI components by means of:
    * Image patterns;
    * UIA API in [Windows](https://docs.microsoft.com/en-us/dotnet/framework/ui-automation/ui-automation-overview) and [Mono Linux](https://github.com/mono/uia2atk) applications.
* Emulate user acivity:
    * Keyboard;
    * Mouse
